@@ -67,10 +67,10 @@ void DocActionFmt::Exec(bool bInteractive)
 		{
 			int nStart  = min(nCursor, nSelection);
 			int nEnd    = max(nCursor, nSelection);
-			
+
 			m_nStartOffset = nStart;
-			m_nEndOffset   = nEnd;	
-			
+			m_nEndOffset   = nEnd;
+
 			bExists = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.IsRangeFormatted(m_nStartOffset, m_nEndOffset, m_nOperationTag);
 
 			//start color picker if required
@@ -123,7 +123,7 @@ void DocActionFmt::Exec(bool bInteractive)
 					gtk_color_selection_get_current_color(colorsel, &color);
 					gtk_widget_destroy(picker);
 				}
-				
+
 				m_color = color;
 				if(FMT_TXT_COLOR_BEGIN == m_nOperationTag)
 					g_rgbTextColor = color;		//remember last used color
@@ -136,12 +136,12 @@ void DocActionFmt::Exec(bool bInteractive)
 	bExists = g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.IsRangeFormatted(m_nStartOffset, m_nEndOffset, m_nOperationTag);
 	if(bExists){
 		g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.ClearFormatRange(m_nStartOffset, m_nEndOffset, m_nOperationTag);
-		RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false);
+		RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false, m_nStartOffset, m_nEndOffset);
 	}
 	else{
 		g_doc.GetNodeByIdx(m_nNodeIdx).m_lstTxtFmt.AddFormatRange(m_nStartOffset, m_nEndOffset, m_nOperationTag, m_color);
 		if(FMT_NONE == m_nOperationTag)
-			RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false);
+			RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false, m_nStartOffset, m_nEndOffset);
 	}
 
 	textview_selection_changed(NULL, NULL, NULL, NULL);
@@ -184,11 +184,11 @@ void DocActionFmt::Undo()
 		}
 	}
 
-	//refresh text format 
+	//refresh text format
 	//TOFIX this is not optimal for long node text, we should refresh only the range where this tag was placed
 	if(m_nNodeIdx == GetSelectedNodeIdx())
 	{
-		RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false);
+		RefreshTextFormat(g_doc.GetNodeByIdx(m_nNodeIdx), false, m_nStartOffset, m_nEndOffset);
 		textview_selection_changed(NULL, NULL, NULL, NULL);
 	}
 }
