@@ -16,6 +16,12 @@
 #include "config.h"
 #include <gdk/gdkkeysyms.h>
 
+#ifdef HAVE_GTKSOURCEVIEW
+	#include <gtksourceview/gtksourceview.h>
+	#include <gtksourceview/gtksourcelanguage.h>
+	#include <gtksourceview/gtksourcelanguagemanager.h>
+#endif
+
 #ifdef _WIN32
  #ifndef __MINGW32__
    #ifndef snprintf
@@ -77,7 +83,8 @@ void NodePropertiesDlg::Create()
 
 	//fill internal icons combo
 	GtkWidget *cbo2	= lookup_widget(m_pDialog, "comboboxentry2");
-	for (int i=ICON_INTERNAL_FIRST; i<=ICON_INTERNAL_LAST; i++)
+	int i;
+	for (i=ICON_INTERNAL_FIRST; i<=ICON_INTERNAL_LAST; i++)
 		gtk_combo_box_append_text(GTK_COMBO_BOX(cbo2), InternalIcon_Index2Name(i));
 
 	//select first entry in combo (must not be empty selection)
@@ -98,23 +105,48 @@ void NodePropertiesDlg::Create()
 	//select first entry in combo
 	gtk_combo_box_set_active(GTK_COMBO_BOX(cbo3), 0);
 
+#ifdef HAVE_GTKSOURCEVIEW
+	//fill source language combo
+	GtkWidget *cbolang = lookup_widget(m_pDialog, "source_lang_combo");
+	// first entry is empty - empty means no source language selected
+	gtk_combo_box_append_text(GTK_COMBO_BOX(cbolang), "");
+	GtkSourceLanguageManager *manager = gtk_source_language_manager_get_default();
+	const gchar * const *languages = gtk_source_language_manager_get_language_ids(manager);
+
+	int active = -1;
+	i = 0;
+	while (*languages != NULL)
+	{
+		i++;
+		gtk_combo_box_append_text(GTK_COMBO_BOX(cbolang), *languages);
+		if (0 == strcmp(m_strSourceLanguage.c_str(), *languages))
+		{
+			active = i;
+		}
+		++languages;
+	}
+	//select active entry in combo
+	if(active >= 0)
+		gtk_combo_box_set_active(GTK_COMBO_BOX(cbolang), active);
+#endif
+
 	//set dates (read only)
 	GtkWidget *label_created	= lookup_widget(m_pDialog, "label_created");
 	GtkWidget *label_modified	= lookup_widget(m_pDialog, "label_modified");
-	
+
 	//display node dates
 	std::string strTxt;
 	FormatTime(m_nCreated, strTxt);
 	gtk_label_set_text(GTK_LABEL(label_created), strTxt.c_str());
 	FormatTime(m_nModified, strTxt);
 	gtk_label_set_text(GTK_LABEL(label_modified), strTxt.c_str());
-	
+
 	//set finished
 	GtkWidget *chk_finished	= lookup_widget(m_pDialog, "chk_finished");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chk_finished), m_bFinished);
 }
 
-const char *NodePropertiesDlg::GetNodeTitle()
+std::string NodePropertiesDlg::GetNodeTitle()
 {
 	GtkWidget *entry = lookup_widget(m_pDialog, "entry_node_title");
 	//return gtk_entry_get_text(GTK_ENTRY(entry));
@@ -122,7 +154,10 @@ const char *NodePropertiesDlg::GetNodeTitle()
 	GtkTextIter start,end;
 	gtk_text_buffer_get_start_iter(buffer, &start);
 	gtk_text_buffer_get_end_iter(buffer, &end);
-	return gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+	gchar *pszData = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+	std::string strData = pszData;
+	g_free(pszData);
+	return strData;
 }
 
 void NodePropertiesDlg::RefreshKeywords()
@@ -156,7 +191,7 @@ int NodePropertiesDlg::GetIconType()
 
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_none)))
 		return ICON_NONE;
-	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_internal))) 
+	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_internal)))
 		return ICON_INTERNAL;
 	return ICON_CUSTOM;
 }
@@ -186,7 +221,7 @@ void NodePropertiesDlg::SetIconType(int nType)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ico_none), TRUE);
 		on_icon_none_clicked(NULL, this);
 	}
-	else if(ICON_CUSTOM == nType) 
+	else if(ICON_CUSTOM == nType)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ico_custom), TRUE);
 	else
 	{
@@ -239,7 +274,7 @@ void NodePropertiesDlg::KeywordAdd()
 			}
 			g_free(value);
 		}
-		
+
 		TRACE("Append tag\n");
 
 		//add the keyword
@@ -274,7 +309,7 @@ void NodePropertiesDlg::KeywordRemove()
 			g_free(value);
 		}
 	}
-	
+
 	//TOFIX how to clear entry part of the combo
 	//gtk_combo_box_set_active(GTK_COMBO_BOX(cbo3), -1);
 }
@@ -297,6 +332,10 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	GtkWidget *entry4;
 	GtkWidget *comboboxentry3;
 	GtkWidget *hbox3;
+#ifdef HAVE_GTKSOURCEVIEW
+	GtkWidget *source_lang_combo;
+	GtkWidget *source_lang_label;
+#endif
 	GtkWidget *label24;
 	GtkWidget *image1;
 	GtkWidget *addbtn;
@@ -312,7 +351,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	GtkWidget *label_modified;
 	GtkWidget *chk_finished;
 	GtkWidget *scrolledwindow1;
-	
+
 	node_properties_dialog = gtk_dialog_new ();
 	gtk_window_set_title (GTK_WINDOW (node_properties_dialog), _("Node Properties"));
 	gtk_window_set_type_hint (GTK_WINDOW (node_properties_dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
@@ -320,7 +359,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 
 	dialog_vbox5 = GTK_DIALOG (node_properties_dialog)->vbox;
 	gtk_widget_show (dialog_vbox5);
-	
+
 	table4 = gtk_table_new (2, 4, FALSE);
 	gtk_widget_show (table4);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox5), table4, TRUE, TRUE, 0);
@@ -331,7 +370,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 		(GtkAttachOptions) (GTK_FILL),
 		(GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label21), 0, 0.5);
-	
+
 	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (scrolledwindow1);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -356,7 +395,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	gtk_accel_group_connect (accel_group, 'T', (GdkModifierType)(GDK_CONTROL_MASK|GDK_SHIFT_MASK), GTK_ACCEL_VISIBLE, closure);
 	g_closure_unref (closure);
 	gtk_window_add_accel_group (GTK_WINDOW (node_properties_dialog), accel_group);
-	
+
 	label25 = gtk_label_new (_("Created:"));
 	gtk_widget_show (label25);
 	gtk_table_attach (GTK_TABLE (table4), label25, 0, 1, 1, 2,
@@ -390,7 +429,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	gtk_table_attach (GTK_TABLE (table4), vbox10, 0, 4, 2, 3,
 		(GtkAttachOptions) (GTK_FILL),
 		(GtkAttachOptions) (GTK_FILL), 0, 0);
-	
+
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox2);
 	gtk_box_pack_start (GTK_BOX (vbox10), hbox2, FALSE, FALSE, 0);
@@ -436,7 +475,7 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	gtk_table_attach (GTK_TABLE (table6), comboboxentry2, 1, 2, 1, 2,
 		(GtkAttachOptions) (GTK_FILL),
 		(GtkAttachOptions) (GTK_FILL), 0, 0);
-	
+
 	entry4 = gtk_entry_new ();
 	gtk_entry_set_editable (GTK_ENTRY(entry4), FALSE);
 	gtk_widget_show (entry4);
@@ -470,27 +509,42 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	addbtn = gtk_button_new_with_mnemonic (_("Add"));
 	gtk_widget_show (addbtn);
 	gtk_box_pack_start (GTK_BOX (hbox3), addbtn, TRUE, TRUE, 0);
-	
+
 	removebtn = gtk_button_new_with_mnemonic (_("Remove"));
 	gtk_widget_show (removebtn);
 	gtk_box_pack_start (GTK_BOX (hbox3), removebtn, TRUE, TRUE, 0);
 
-	chk_finished = gtk_check_button_new_with_mnemonic (_("Mark node as finished"));
+	chk_finished = gtk_check_button_new_with_mnemonic (_("Mark node as Completed"));
 	gtk_widget_show (chk_finished);
 	gtk_table_attach (GTK_TABLE (table4), chk_finished, 0, 2, 6, 7,
 		(GtkAttachOptions) (GTK_FILL),
 		(GtkAttachOptions) (0), 0, 0);
 
+#ifdef HAVE_GTKSOURCEVIEW
+	source_lang_label = gtk_label_new (_("Source Language:"));
+	gtk_widget_show (source_lang_label);
+	gtk_table_attach (GTK_TABLE (table4), source_lang_label, 0, 1, 7, 8,
+		(GtkAttachOptions) (GTK_FILL),
+		(GtkAttachOptions) (0), 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (source_lang_label), 0, 0.5);
+
+	source_lang_combo = gtk_combo_box_entry_new_text ();
+	gtk_widget_show (source_lang_combo);
+	gtk_table_attach (GTK_TABLE (table4), source_lang_combo, 1, 4, 7, 8,
+		(GtkAttachOptions) (GTK_FILL),
+		(GtkAttachOptions) (0), 0, 0);
+#endif
+
 	dialog_action_area5 = GTK_DIALOG (node_properties_dialog)->action_area;
 	gtk_widget_show (dialog_action_area5);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area5), GTK_BUTTONBOX_END);
-	
+
 	cancelbutton5 = gtk_button_new_from_stock ("gtk-cancel");
 	gtk_widget_show (cancelbutton5);
 	gtk_dialog_add_action_widget (GTK_DIALOG (node_properties_dialog), cancelbutton5, GTK_RESPONSE_CANCEL);
 	GTK_WIDGET_SET_FLAGS (cancelbutton5, GTK_CAN_DEFAULT);
 	g_cancelbtn = cancelbutton5;
-	
+
 	okbutton5 = gtk_button_new_from_stock ("gtk-ok");
 	gtk_widget_show (okbutton5);
 	gtk_dialog_add_action_widget (GTK_DIALOG (node_properties_dialog), okbutton5, GTK_RESPONSE_OK);
@@ -534,7 +588,9 @@ GtkWidget* NodePropertiesDlg::create_node_properties_dialog ()
 	GLADE_HOOKUP_OBJECT (node_properties_dialog, label_created, "label_created");
 	GLADE_HOOKUP_OBJECT (node_properties_dialog, label_modified, "label_modified");
 	GLADE_HOOKUP_OBJECT (node_properties_dialog, chk_finished, "chk_finished");
-
+#ifdef HAVE_GTKSOURCEVIEW
+	GLADE_HOOKUP_OBJECT (node_properties_dialog, source_lang_combo, "source_lang_combo");
+#endif
 
 	return node_properties_dialog;
 }
@@ -571,7 +627,7 @@ void on_icon_internal_clicked(GtkMenuItem *menuitem, gpointer user_data)
 		GtkWidget *cbo2		= lookup_widget(pDlg->m_pDialog, "comboboxentry2");
 		GtkWidget *entry4	= lookup_widget(pDlg->m_pDialog, "entry4");
 		GtkWidget *button	= lookup_widget(pDlg->m_pDialog, "button_xpm_select");
-		
+
 		gtk_widget_set_sensitive(cbo2, TRUE);
 		gtk_widget_set_sensitive(entry4, FALSE);
 		gtk_widget_set_sensitive(button, FALSE);
@@ -587,7 +643,7 @@ void on_icon_internal_clicked(GtkMenuItem *menuitem, gpointer user_data)
 void on_icon_custom_clicked(GtkMenuItem *menuitem, gpointer user_data)
 {
 	NodePropertiesDlg *pDlg = (NodePropertiesDlg *)user_data;
-	
+
 	GtkWidget *radio_ico_custom = lookup_widget(pDlg->m_pDialog, "radio_ico_custom");
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_custom)))
 	{
@@ -610,11 +666,13 @@ void on_icon_custom_clicked(GtkMenuItem *menuitem, gpointer user_data)
 void on_xpm_select_clicked(GtkMenuItem *menuitem, gpointer user_data)
 {
 	FileDialog dlg;
-	dlg.AddFilter(_("All supported icon formats (*.xpm,*.ico,*.png,*.jpg)"), "*.xpm|*.ico|*.png|*.jpg");
+	dlg.AddFilter(_("All supported icon formats (*.xpm,*.ico,*.png,*.jpg,*.gif)"), "*.xpm|*.ico|*.png|*.jpg|*.gif");
 	dlg.AddFilter(_("XPM icon file (*.xpm)"), "*.xpm");
 	dlg.AddFilter(_("Icon file (*.ico)"), "*.ico");
 	dlg.AddFilter(_("PNG file format (*.png)"), "*.png");
 	dlg.AddFilter(_("JPEG file format (*.jpg)"), "*.jpg");
+	dlg.AddFilter(_("GIF file format (*.gif)"), "*.gif");
+
 
 	//set initial directory from INI (store last used)
 	std::string strDefaultDir;
@@ -727,7 +785,7 @@ const char *combo_get_text(GtkWidget *cbo3)
 {
 	//FIX: gtk_combo_box_get_active_text API crashes on Zaurus
 #ifdef _ZAURUS_BUILD
-	return gtk_entry_get_text(GTK_ENTRY(GTK_BIN(cbo3)->child));	
+	return gtk_entry_get_text(GTK_ENTRY(GTK_BIN(cbo3)->child));
 #else
  #if GTK_CHECK_VERSION(2,6,0) //new API //TOFIX set proper version//
 	return gtk_combo_box_get_active_text (GTK_COMBO_BOX(cbo3));
@@ -748,7 +806,7 @@ const char *combo_get_text(GtkWidget *cbo3)
 			//g_free(value);
 		}
 		else
-			return "";	
+			return "";
 	}
 	else //TOFIX get text from entry
 		return "";
@@ -790,4 +848,14 @@ gint entry_keyboard_handler(GtkWidget *widget, GdkEventKey *event)
 	}
 
 	return FALSE;
-} 
+}
+
+#ifdef HAVE_GTKSOURCEVIEW
+std::string NodePropertiesDlg::GetSourceLanguage()
+{
+		GtkWidget *entry = lookup_widget(m_pDialog, "source_lang_combo");
+    std::string strData = combo_get_text(entry);
+    m_strSourceLanguage = strData;
+		return strData;
+}
+#endif
