@@ -32,6 +32,8 @@
 #include "interface.h"
 #include "gui/FileDialog.h"
 #include "lib/IniFile.h"
+#include <stdlib.h>
+#include <gdk/gdkkeysyms.h>
 
 #define ICON_NONE    -2
 #define ICON_CUSTOM  -1
@@ -50,6 +52,7 @@ extern bool g_bCloseDlgOnTextEnter;
 extern bool g_bAutoSaveOnClose;
 extern bool g_bSkipMemOnlyAutosave;
 extern bool g_bExportDataAsSeparateFile;
+extern bool g_bDrawTextviewExpose;
 extern IniFile g_objIni;
 extern bool g_bTreeToTheRight;
 extern GdkColor g_linkColor;
@@ -58,6 +61,8 @@ extern bool g_bWrapTree;
 int g_nDefaultNodeIconType = ICON_NONE;
 std::string g_strDefaultIconFile;
 
+extern GdkColor g_rgbTextViewBkColor;
+
 void restart_autosave();
 void restart_enc_unload_timer();
 static void on_autosave_checked (GtkMenuItem *menuitem, gpointer user_data);
@@ -72,6 +77,9 @@ static void on_icon_internal_clicked (GtkMenuItem *menuitem, gpointer user_data)
 static void on_icon_custom_clicked (GtkMenuItem *menuitem, gpointer user_data);
 static void on_xpm_select_clicked (GtkMenuItem *menuitem, gpointer user_data);
 static void on_internal_combo_selected (GtkComboBox *widget, gpointer user_data);
+static gboolean on_numeric_entry_keypress(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
+static gboolean on_numeric_entry_changed(GtkWidget *widget, GdkEventFocus *event, gpointer user_data);
+
 void update_tree_wrap();
 
 void RefreshTextViewCaretColor(GdkColor &BkColor);
@@ -79,7 +87,9 @@ const char *combo_get_text(GtkWidget *cbo3);
 const char *InternalIcon_Index2Name(int nIndex);
 const char **InternalIcon_GetFromIdx(int);
 int InternalIcon_Name2Index(const char *);
-
+bool copy_file(const char *szFrom, const char *szTo);
+bool is_portable_mode();
+std::string CalcLauncherPath();
 
 OptionsDialog::OptionsDialog()
 {
@@ -110,12 +120,14 @@ void OptionsDialog::OnDialogInit()
 	GtkWidget *regformats_btn = lookup_widget(m_pDialog, "regformats_btn");
 	GtkWidget *wraptext_btn	  = lookup_widget(m_pDialog, "wraptext_btn");
 	GtkWidget *wraptree_btn	  = lookup_widget(m_pDialog, "wraptree_btn");
+	GtkWidget *treelines_btn  = lookup_widget(m_pDialog, "treelines_btn");
 	GtkWidget *fontbutton2	  = lookup_widget(m_pDialog, "fontbutton2");
 	GtkWidget *fontbutton3	  = lookup_widget(m_pDialog, "fontbutton3");
 	GtkWidget *comboboxentry1 = lookup_widget(m_pDialog, "comboboxentry1");
 	GtkWidget *comboboxentry2 = lookup_widget(m_pDialog, "comboboxentry2");
 	GtkWidget *min2tray_btn   = lookup_widget(m_pDialog, "min2tray_btn");
 	GtkWidget *close2tray_btn = lookup_widget(m_pDialog, "close2tray_btn");
+	GtkWidget *drawgray_btn = lookup_widget(m_pDialog, "drawgray_btn");
 	GtkWidget *enterhandle_btn = lookup_widget(m_pDialog, "enterhandle_btn");
 	GtkWidget *last_pos_btn   = lookup_widget(m_pDialog, "last_position_btn");
 	GtkWidget *autosave_btn   = lookup_widget(m_pDialog, "autosave_btn");
@@ -131,8 +143,8 @@ void OptionsDialog::OnDialogInit()
 	GtkWidget *toc_depth_entry= lookup_widget(m_pDialog, "toc_depth_entry");
 	GtkWidget *convert_image_links_btn = lookup_widget(m_pDialog, "convert_image_links_btn");
 	GtkWidget *embedd_css_btn = lookup_widget(m_pDialog, "embedd_css_btn");
-	GtkWidget *autosave_on_close_btn = lookup_widget(m_pDialog, "autosave_on_close_btn"); 
-	GtkWidget *export_as_separate_files_btn = lookup_widget(m_pDialog, "export_as_separate_files_btn"); 
+	GtkWidget *autosave_on_close_btn = lookup_widget(m_pDialog, "autosave_on_close_btn");
+	GtkWidget *export_as_separate_files_btn = lookup_widget(m_pDialog, "export_as_separate_files_btn");
 	GtkWidget *tree_right_btn = lookup_widget(m_pDialog, "tree_right_btn");
 	GtkWidget *lock_memory_btn = lookup_widget(m_pDialog, "lock_memory_btn");
 	GtkWidget *enc_unload_btn = lookup_widget(m_pDialog, "enc_unload_btn");
@@ -146,7 +158,7 @@ void OptionsDialog::OnDialogInit()
 	bool bBootstart;
 	if(g_objIni.GetValue("Startup", "BootStart", bBootstart))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bootstart_btn), bBootstart);
-	
+
 	bool bMaximize;
 	if(g_objIni.GetValue("Startup", "Maximize", bMaximize))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(maximize_btn), bMaximize);
@@ -162,11 +174,11 @@ void OptionsDialog::OnDialogInit()
 	bool bRestoreLastPos = true;
 	g_objIni.GetValue("Startup", "RestoreLastPosition", bRestoreLastPos, 1);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(last_pos_btn), bRestoreLastPos);
-	
+
 	bool bRegisterFormats;
 	if(g_objIni.GetValue("Startup", "RegisterFormats", bRegisterFormats))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(regformats_btn), bRegisterFormats);
-	
+
 	bool bWrapText;
 	if(g_objIni.GetValue("Display", "WrapText", bWrapText))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wraptext_btn), bWrapText);
@@ -175,14 +187,22 @@ void OptionsDialog::OnDialogInit()
 	if(g_objIni.GetValue("Display", "WrapTree", bWrapTree))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wraptree_btn), bWrapTree);
 
+	bool bShowTreeLines;
+	if(g_objIni.GetValue("Display", "ShowTreeLines", bShowTreeLines))
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(treelines_btn), bShowTreeLines);
+
 	bool bMin2Tray;
 	if(g_objIni.GetValue("Display", "MinimizeToTray", bMin2Tray))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(min2tray_btn), bMin2Tray);
-	
+
 	bool bClose2Tray;
 	if(g_objIni.GetValue("Display", "CloseToTray", bClose2Tray))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(close2tray_btn), bClose2Tray);
-	
+
+	bool bDrawGray;
+	if(g_objIni.GetValue("Display", "DrawGrayTextView", bDrawGray))
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(drawgray_btn), bDrawGray);
+
 	bool bCloseOnEnter;
 	if(g_objIni.GetValue("Default", "CloseDlgOnTxtEnter", bCloseOnEnter))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(enterhandle_btn), bCloseOnEnter);
@@ -273,7 +293,7 @@ void OptionsDialog::OnDialogInit()
 	{
 		//map back from locale to Language name
 		strLang = g_lang.GetLangName(g_lang.GetCatalogAt(i).c_str());
-		gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry1), strLang.c_str()); 
+		gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry1), strLang.c_str());
 	}
 
 	//select current saved INI language in the combo (not necessarily current language)
@@ -346,7 +366,7 @@ void OptionsDialog::OnDialogInit()
 		SetIconValue(g_strDefaultIconFile.c_str());
 
 }
-	
+
 void OptionsDialog::OnDialogOK()
 {
 	GtkWidget *treeview = lookup_widget(window1, "treeview1");
@@ -359,12 +379,14 @@ void OptionsDialog::OnDialogOK()
 	GtkWidget *regformats_btn = lookup_widget(m_pDialog, "regformats_btn");
 	GtkWidget *wraptext_btn	  = lookup_widget(m_pDialog, "wraptext_btn");
 	GtkWidget *wraptree_btn	  = lookup_widget(m_pDialog, "wraptree_btn");
+	GtkWidget *treelines_btn  = lookup_widget(m_pDialog, "treelines_btn");
 	GtkWidget *fontbutton2	  = lookup_widget(m_pDialog, "fontbutton2");
 	GtkWidget *fontbutton3	  = lookup_widget(m_pDialog, "fontbutton3");
 	GtkWidget *comboboxentry1 = lookup_widget(m_pDialog, "comboboxentry1");
 	GtkWidget *comboboxentry2 = lookup_widget(m_pDialog, "comboboxentry2");
 	GtkWidget *min2tray_btn   = lookup_widget(m_pDialog, "min2tray_btn");
 	GtkWidget *close2tray_btn = lookup_widget(m_pDialog, "close2tray_btn");
+	GtkWidget *drawgray_btn = lookup_widget(m_pDialog, "drawgray_btn");
 	GtkWidget *enterhandle_btn = lookup_widget(m_pDialog, "enterhandle_btn");
 	GtkWidget *last_pos_btn   = lookup_widget(m_pDialog, "last_position_btn");
 	GtkWidget *autosave_btn   = lookup_widget(m_pDialog, "autosave_btn");
@@ -380,8 +402,8 @@ void OptionsDialog::OnDialogOK()
 	GtkWidget *toc_depth_entry= lookup_widget(m_pDialog, "toc_depth_entry");
 	GtkWidget *convert_image_links_btn = lookup_widget(m_pDialog, "convert_image_links_btn");
 	GtkWidget *embedd_css_btn = lookup_widget(m_pDialog, "embedd_css_btn");
-	GtkWidget *autosave_on_close_btn = lookup_widget(m_pDialog, "autosave_on_close_btn"); 
-	GtkWidget *export_as_separate_files_btn = lookup_widget(m_pDialog, "export_as_separate_files_btn"); 
+	GtkWidget *autosave_on_close_btn = lookup_widget(m_pDialog, "autosave_on_close_btn");
+	GtkWidget *export_as_separate_files_btn = lookup_widget(m_pDialog, "export_as_separate_files_btn");
 	GtkWidget *tree_right_btn = lookup_widget(m_pDialog, "tree_right_btn");
 	GtkWidget *lock_memory_btn = lookup_widget(m_pDialog, "lock_memory_btn");
 	GtkWidget *enc_unload_btn = lookup_widget(m_pDialog, "enc_unload_btn");
@@ -389,7 +411,7 @@ void OptionsDialog::OnDialogOK()
 	GtkWidget *system_locale_btn = lookup_widget(m_pDialog, "system_locale_btn");
 	GtkWidget *no_mem_autosave_btn = lookup_widget(m_pDialog, "no_mem_autosave_btn");
 
-	
+
 	//
 	// write options back to the INI (and activate them if necessary)
 	//
@@ -399,7 +421,26 @@ void OptionsDialog::OnDialogOK()
 		#ifdef _WIN32
 			//register program loading at boot time
 			if(!IsBootKeySet("notecase"))
-				RunProgramAtBoot("notecase", GetAppPath().c_str(), TRUE);	//set
+				if(is_portable_mode())
+					RunProgramAtBoot("notecase", CalcLauncherPath().c_str(), TRUE);	//remove
+				else
+					RunProgramAtBoot("notecase", GetAppPath().c_str(), TRUE);	//set
+		#else
+			//register program loading at boot time
+			std::string strDir = GetHomeDir();
+			EnsureTerminated(strDir, '/');
+			strDir += ".config/autostart/";
+			EnsureDirExists(strDir);
+			strDir += "notecase.desktop";
+
+			std::string strSrcFile;
+			#ifdef _NOKIA_MAEMO
+				strSrcFile = "/usr/share/applications/hildon/notecase.desktop";
+			#else
+				strSrcFile = "/usr/share/applications/notecase.desktop";
+			#endif
+			//copy file
+			copy_file(strSrcFile.c_str(), strDir.c_str()); //TOFIX error report
 		#endif
 	}
 	else
@@ -408,7 +449,18 @@ void OptionsDialog::OnDialogOK()
 		#ifdef _WIN32
 			//unregister program loading at boot time
 			if(IsBootKeySet("notecase"))
-				RunProgramAtBoot("notecase", GetAppPath().c_str(), FALSE);	//remove
+				if(is_portable_mode())
+					RunProgramAtBoot("notecase", CalcLauncherPath().c_str(), FALSE);	//remove
+				else
+					RunProgramAtBoot("notecase", GetAppPath().c_str(), FALSE);	//remove
+		#else
+			//unregister program loading at boot time
+			std::string strDir = GetHomeDir();
+			EnsureTerminated(strDir, '/');
+			strDir += ".config/autostart/";
+			EnsureDirExists(strDir);
+			strDir += "notecase.desktop";
+			remove(strDir.c_str());
 		#endif
 	}
 
@@ -467,6 +519,17 @@ void OptionsDialog::OnDialogOK()
 		g_bWrapTree=false;
 	}
 
+	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(treelines_btn)))
+	{
+		g_objIni.SetValue("Display", "ShowTreeLines", 1);
+		g_tree.SetTreeLines(true);
+	}
+	else
+	{
+		g_objIni.SetValue("Display", "ShowTreeLines", 0);
+		g_tree.SetTreeLines(false);
+	}
+
 #if GTK_CHECK_VERSION(2,4,0) //define minimal version for this api
 	//set fonts
 	const gchar *szFont1 = gtk_font_button_get_font_name(GTK_FONT_BUTTON(fontbutton2));
@@ -478,7 +541,7 @@ void OptionsDialog::OnDialogOK()
 	PangoFontDescription *desc2 = pango_font_description_from_string(szFont2);
 	gtk_widget_modify_font(textview, desc2);
 	g_objIni.SetValue("Display", "TextFont", szFont2);//save font description
-#endif			
+#endif
 
 	//save text/background colors
 	GdkColor color;
@@ -492,11 +555,13 @@ void OptionsDialog::OnDialogOK()
 	szColor = g_strdup_printf ("#%04x%04x%04x", color1.red, color1.green, color1.blue);
 	g_objIni.SetValue("Display", "BackgroundColor", szColor);
 	g_free(szColor);
-	
+	g_rgbTextViewBkColor = color1;
+
 	//update widgets with new color
 	gtk_widget_modify_text(GTK_WIDGET(textview), GTK_STATE_NORMAL, &color);
 	gtk_widget_modify_text(GTK_WIDGET(treeview), GTK_STATE_NORMAL, &color);
 	gtk_widget_modify_base(GTK_WIDGET(textview), GTK_STATE_NORMAL, &color1);
+	gtk_widget_modify_base(GTK_WIDGET(textview), GTK_STATE_INSENSITIVE, &color1);
 	gtk_widget_modify_base(GTK_WIDGET(treeview), GTK_STATE_NORMAL, &color1);
 	RefreshTextViewCaretColor(color1);
 
@@ -507,7 +572,7 @@ void OptionsDialog::OnDialogOK()
 		"GtkTreeView::odd-row-color=\"#%04x%04x%04x\"\n"
 		"GtkTreeView::even-row-color =\"#%04x%04x%04x\"\n"
 		"}\n"
-		"widget \"*.aaa\" style \"aaa\""; 
+		"widget \"*.aaa\" style \"aaa\"";
 
 	gchar *rc_temp = g_strdup_printf (color_rc,
 								color1.red,
@@ -518,7 +583,7 @@ void OptionsDialog::OnDialogOK()
 								color1.blue);
 	gtk_rc_parse_string (rc_temp);
 	gtk_widget_set_name(treeview, "aaa");
-	gtk_widget_reset_rc_styles (treeview); 
+	gtk_widget_reset_rc_styles (treeview);
 	g_free (rc_temp);
 
 	//save link color
@@ -542,7 +607,7 @@ void OptionsDialog::OnDialogOK()
 	else
 		bUseSystemLang = false;
 	g_objIni.SetValue("Display", "UseSystemLanguage", bUseSystemLang);
-	
+
 	//save selected date/tiem format
 	int nDateTimeFmt = gtk_combo_box_get_active(GTK_COMBO_BOX(comboboxentry2));
 	g_objIni.SetValue("Display", "DateTimeFormat", nDateTimeFmt);
@@ -560,7 +625,18 @@ void OptionsDialog::OnDialogOK()
 	else
 		g_bCloseToTray = false;
 	g_objIni.SetValue("Display", "CloseToTray", g_bCloseToTray);
-	
+
+	//"draw gray" setting
+	bool bDrawGray;
+	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(drawgray_btn)))
+		bDrawGray = true;
+	else
+		bDrawGray = false;
+	g_objIni.SetValue("Display", "DrawGrayTextView", bDrawGray);
+
+	if(bDrawGray != g_bDrawTextviewExpose)
+		gtkMessageBox(_("Some of the changed options require program restart!"));
+
 	//how to handle enter key in text widgets
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(enterhandle_btn)))
 		g_bCloseDlgOnTextEnter = true;
@@ -574,7 +650,7 @@ void OptionsDialog::OnDialogOK()
 	else
 		g_bTreeToTheRight = false;
 	g_objIni.SetValue("Display", "TreeToTheRight", g_bTreeToTheRight);
-	
+
 	//"restore position" settings
 	bool bRestoreLastPos = false;
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(last_pos_btn)))
@@ -720,7 +796,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GtkWidget *checkbutton5;
 	GtkWidget *label6;
 	GtkWidget *label7;
-	GtkWidget *comboboxentry1; 
+	GtkWidget *comboboxentry1;
 	GtkWidget *label8;
 	GtkWidget *checkbutton6;
 	GtkWidget *label19;
@@ -735,7 +811,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GtkWidget *colorbtn3;
 	GtkWidget *entry2;
 	GtkWidget *label25;
-	GtkWidget *comboboxentry2; 
+	GtkWidget *comboboxentry2;
 	GtkWidget *table3;
 	GtkWidget *checkbutton10;
 	GtkWidget *entry3;
@@ -754,6 +830,8 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GtkWidget *checkbutton23;
 	GtkWidget *checkbutton24;
 	GtkWidget *checkbutton27;
+	GtkWidget *checkbutton30;
+
 //
 	GtkWidget *button_xpm_select;
 	GtkWidget *image1;
@@ -765,7 +843,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GtkWidget *entry14;
 	GtkWidget *label23;
 	GtkWidget *comboboxentry12;
-
+	GtkWidget *checkbutton32;
 
 	Options = gtk_dialog_new ();
 	gtk_window_set_title (GTK_WINDOW (Options), _("Options"));
@@ -777,7 +855,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 #endif
 	if(parent)
 		gtk_window_set_transient_for(GTK_WINDOW (Options), GTK_WINDOW(parent));   //set parent
-		
+
 #if GTK_CHECK_VERSION(2,4,0) //new API TOFIX set proper version
 	#ifndef _WIN32  //TOFIX API is buggy on Win32 (kills modal dialog state)
 		//gtk_window_set_keep_above(GTK_WINDOW (Options), TRUE);
@@ -786,11 +864,11 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (Options), TRUE);
 	gtk_window_set_resizable (GTK_WINDOW (Options), FALSE);
 	gtk_widget_realize(Options);
-	gdk_window_set_decorations(Options->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE)); 
+	gdk_window_set_decorations(Options->window, (GdkWMDecoration)(GDK_DECOR_BORDER|GDK_DECOR_TITLE));
 
 	dialog_vbox3 = GTK_DIALOG (Options)->vbox;
 	gtk_widget_show (dialog_vbox3);
-	
+
 	notebook1 = gtk_notebook_new ();
 	gtk_widget_show (notebook1);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox3), notebook1, TRUE, TRUE, 0);
@@ -798,7 +876,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	//
 	// 1st tab
 	//
-	
+
 	vbox4 = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vbox4);
 	gtk_container_add (GTK_CONTAINER (notebook1), vbox4);
@@ -806,25 +884,19 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	checkbutton0 = gtk_check_button_new_with_mnemonic (_("Start at logon"));
 	gtk_widget_show (checkbutton0);
 	gtk_box_pack_start (GTK_BOX (vbox4), checkbutton0, FALSE, FALSE, 0);
-#ifndef _WIN32
-	gtk_widget_set_sensitive (checkbutton0, FALSE); //TOFIX temp disable until implemented
-#endif
 
 	checkbutton1 = gtk_check_button_new_with_mnemonic (_("Maximize on startup"));
 	gtk_widget_show (checkbutton1);
 	gtk_box_pack_start (GTK_BOX (vbox4), checkbutton1, FALSE, FALSE, 0);
-	
+
 	checkbutton2 = gtk_check_button_new_with_mnemonic (_("Allow single instance only"));
 	gtk_widget_show (checkbutton2);
 	gtk_box_pack_start (GTK_BOX (vbox4), checkbutton2, FALSE, FALSE, 0);
-#ifndef _WIN32
-	gtk_widget_set_sensitive (checkbutton2, FALSE); //TOFIX temp disable until implemented
-#endif
-	
+
 	checkbutton3 = gtk_check_button_new_with_mnemonic (_("Reload last used document"));
 	gtk_widget_show (checkbutton3);
 	gtk_box_pack_start (GTK_BOX (vbox4), checkbutton3, FALSE, FALSE, 0);
-	
+
 	checkbutton4 = gtk_check_button_new_with_mnemonic (_("Register document formats"));
 	gtk_widget_show (checkbutton4);
 	gtk_box_pack_start (GTK_BOX (vbox4), checkbutton4, FALSE, FALSE, 0);
@@ -836,7 +908,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	label5 = gtk_label_new (_("Startup"));
 	gtk_widget_show (label5);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label5);
-	
+
 	//
 	// 2nd tab
 	//
@@ -881,7 +953,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	colorbtn1 = gtk_color_button_new();
 	gtk_widget_show (colorbtn1);
 	gtk_table_attach (GTK_TABLE (table1), colorbtn1, 1, 2, 4, 5, (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 1);
-	
+
 	colorbtn2 = gtk_color_button_new();
 	gtk_widget_show (colorbtn2);
 	gtk_table_attach (GTK_TABLE (table1), colorbtn2, 2, 3, 4, 5, (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 1);
@@ -910,7 +982,11 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 
 	checkbutton27 = gtk_check_button_new_with_mnemonic (_("Wrap titles tree"));
 	gtk_widget_show (checkbutton27);
-	gtk_table_attach (GTK_TABLE (table1), checkbutton27, 1, 3, 7, 8, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_table_attach (GTK_TABLE (table1), checkbutton27, 1, 2, 7, 8, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
+	checkbutton30 = gtk_check_button_new_with_mnemonic (_("Show tree lines"));
+	gtk_widget_show (checkbutton30);
+	gtk_table_attach (GTK_TABLE (table1), checkbutton30, 2, 3, 7, 8, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	label3 = gtk_label_new (_("Display"));
 	gtk_widget_show (label3);
@@ -952,7 +1028,11 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 
 	checkbutton15 = gtk_check_button_new_with_mnemonic (_("Show node tree on the right"));
 	gtk_widget_show (checkbutton15);
-	gtk_table_attach (GTK_TABLE (table1), checkbutton15, 0, 2, 3, 4, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_table_attach (GTK_TABLE (table1), checkbutton15, 0, 1, 3, 4, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
+	checkbutton32 = gtk_check_button_new_with_mnemonic (_("Draw message over inactive text view"));
+	gtk_widget_show (checkbutton32);
+	gtk_table_attach (GTK_TABLE (table1), checkbutton32, 1, 2, 3, 4, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	checkbutton6 = gtk_check_button_new_with_mnemonic (_("Minimize to tray"));
 	gtk_widget_show (checkbutton6);
@@ -978,7 +1058,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (table2);
 	gtk_container_add (GTK_CONTAINER (notebook1), table2);
 
-	checkbutton8 = gtk_check_button_new_with_mnemonic (_("Autosave document every:"));
+	checkbutton8 = gtk_check_button_new_with_mnemonic (_("Autosave to temporary crash-protection copy every:"));
 	gtk_widget_show (checkbutton8);
 	gtk_table_attach (GTK_TABLE (table2), checkbutton8, 0, 2, 0, 1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -986,6 +1066,8 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (entry1);
 	gtk_widget_set_sensitive (entry1, FALSE);
 	gtk_table_attach (GTK_TABLE (table2), entry1, 0, 1, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 2, 0);
+	g_signal_connect (entry1, "key-press-event", G_CALLBACK (on_numeric_entry_keypress), this);
+	g_signal_connect (entry1, "focus-out-event", G_CALLBACK (on_numeric_entry_changed), GINT_TO_POINTER(30));
 
 	label20 = gtk_label_new (_("seconds"));
 	gtk_widget_show (label20);
@@ -1005,6 +1087,8 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (entry5);
 	gtk_widget_set_sensitive (entry5, FALSE);
 	gtk_table_attach (GTK_TABLE (table2), entry5, 0, 1, 4, 5, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 2, 0);
+	g_signal_connect (entry5, "key-press-event", G_CALLBACK (on_numeric_entry_keypress), this);
+	g_signal_connect (entry5, "focus-out-event", G_CALLBACK (on_numeric_entry_changed), GINT_TO_POINTER(1));
 
 	label20 = gtk_label_new (_("backup files"));
 	gtk_widget_show (label20);
@@ -1035,6 +1119,8 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (entry3);
 	gtk_widget_set_sensitive (entry3, FALSE);
 	gtk_table_attach (GTK_TABLE (table3), entry3, 0, 1, 1, 2, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 2, 0);
+	g_signal_connect (entry3, "key-press-event", G_CALLBACK (on_numeric_entry_keypress), this);
+	g_signal_connect (entry3, "focus-out-event", G_CALLBACK (on_numeric_entry_changed), GINT_TO_POINTER(1));
 
 	checkbutton11 = gtk_check_button_new_with_mnemonic (_("Export link to image file as the image tag"));
 	gtk_widget_show (checkbutton11);
@@ -1066,7 +1152,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 #ifdef _WIN32
 	gtk_widget_set_sensitive(checkbutton16, FALSE);
 #endif
-	
+
 	label20 = gtk_label_new (_("Security"));
 	gtk_widget_show (label20);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 5), label20);
@@ -1079,6 +1165,8 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (entry4);
 	gtk_widget_set_sensitive (entry4, FALSE);
 	gtk_table_attach (GTK_TABLE (table1), entry4, 0, 1, 2, 3, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 2, 0);
+	g_signal_connect (entry4, "key-press-event", G_CALLBACK (on_numeric_entry_keypress), this);
+	g_signal_connect (entry4, "focus-out-event", G_CALLBACK (on_numeric_entry_changed), GINT_TO_POINTER(1));
 
 	label20 = gtk_label_new (_("minutes"));
 	gtk_widget_show (label20);
@@ -1129,7 +1217,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_table_attach (GTK_TABLE (table6), comboboxentry12, 1, 3, 2, 3,
 		(GtkAttachOptions) (GTK_FILL),
 		(GtkAttachOptions) (GTK_FILL), 0, 0);
-	
+
 	entry14 = gtk_entry_new ();
 	gtk_entry_set_editable (GTK_ENTRY(entry14), FALSE);
 	gtk_widget_show (entry14);
@@ -1173,7 +1261,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	gtk_widget_show (cancelbutton3);
 	gtk_dialog_add_action_widget (GTK_DIALOG (Options), cancelbutton3, GTK_RESPONSE_CANCEL);
 	GTK_WIDGET_SET_FLAGS (cancelbutton3, GTK_CAN_DEFAULT);
-	
+
 	okbutton3 = gtk_button_new_from_stock ("gtk-ok");
 	gtk_widget_show (okbutton3);
 	gtk_container_add (GTK_CONTAINER(dialog_action_area3), okbutton3);
@@ -1191,7 +1279,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	g_signal_connect (radio_ico_custom,	"clicked", G_CALLBACK (on_icon_custom_clicked), this);
 	g_signal_connect (button_xpm_select,	"clicked", G_CALLBACK (on_xpm_select_clicked), this);
 	g_signal_connect (comboboxentry12,	"changed", G_CALLBACK (on_internal_combo_selected), this);
-	
+
 	// Store pointers to all widgets, for use by lookup_widget()
 	GLADE_HOOKUP_OBJECT_NO_REF (Options, Options, "Options");
 	GLADE_HOOKUP_OBJECT_NO_REF (Options, dialog_vbox3, "dialog_vbox3");
@@ -1204,6 +1292,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GLADE_HOOKUP_OBJECT (Options, checkbutton4, "regformats_btn");
 	GLADE_HOOKUP_OBJECT (Options, checkbutton5, "wraptext_btn");
 	GLADE_HOOKUP_OBJECT (Options, checkbutton27, "wraptree_btn");
+	GLADE_HOOKUP_OBJECT (Options, checkbutton30, "treelines_btn");
 	GLADE_HOOKUP_OBJECT (Options, checkbutton6, "min2tray_btn");
 	GLADE_HOOKUP_OBJECT (Options, checkbutton7, "last_position_btn");
 	GLADE_HOOKUP_OBJECT (Options, checkbutton19, "close2tray_btn");
@@ -1251,6 +1340,7 @@ GtkWidget* OptionsDialog::create_options_dialog (GtkWidget* parent)
 	GLADE_HOOKUP_OBJECT (Options, entry14, "entry14");
 	GLADE_HOOKUP_OBJECT (Options, label23, "label23");
 	GLADE_HOOKUP_OBJECT (Options, comboboxentry12, "comboboxentry12");
+	GLADE_HOOKUP_OBJECT (Options, checkbutton32, "drawgray_btn");
 
 	return Options;
 }
@@ -1262,9 +1352,9 @@ void on_autosave_checked (GtkMenuItem *menuitem, gpointer user_data)
 	GtkWidget *autosave_btn = lookup_widget(pDlg->m_pDialog, "autosave_btn");
 	GtkWidget *autosave_fld = lookup_widget(pDlg->m_pDialog, "autosave_fld");
 	GtkWidget *no_mem_autosave_btn = lookup_widget(pDlg->m_pDialog, "no_mem_autosave_btn");
-	
+
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(autosave_btn))){
-		gtk_widget_set_sensitive (autosave_fld, TRUE);	
+		gtk_widget_set_sensitive (autosave_fld, TRUE);
 		gtk_widget_set_sensitive (no_mem_autosave_btn, TRUE);
 	}
 	else{
@@ -1279,9 +1369,9 @@ void on_backup_checked (GtkMenuItem *menuitem, gpointer user_data)
 
 	GtkWidget *backup_btn = lookup_widget(pDlg->m_pDialog, "backup_btn");
 	GtkWidget *backup_fld = lookup_widget(pDlg->m_pDialog, "backup_fld");
-	
+
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(backup_btn)))
-		gtk_widget_set_sensitive (backup_fld, TRUE);	
+		gtk_widget_set_sensitive (backup_fld, TRUE);
 	else
 		gtk_widget_set_sensitive (backup_fld, FALSE);
 }
@@ -1292,9 +1382,9 @@ void on_tabsize_checked (GtkMenuItem *menuitem, gpointer user_data)
 
 	GtkWidget *tab_size_btn = lookup_widget(pDlg->m_pDialog, "custom_tab_size_btn");
 	GtkWidget *tab_size_fld = lookup_widget(pDlg->m_pDialog, "tabsize_fld");
-	
+
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(tab_size_btn)))
-		gtk_widget_set_sensitive (tab_size_fld, TRUE);	
+		gtk_widget_set_sensitive (tab_size_fld, TRUE);
 	else
 		gtk_widget_set_sensitive (tab_size_fld, FALSE);
 }
@@ -1305,9 +1395,9 @@ void on_toc_checked (GtkMenuItem *menuitem, gpointer user_data)
 
 	GtkWidget *use_toc_btn = lookup_widget(pDlg->m_pDialog, "use_toc_btn");
 	GtkWidget *toc_depth_entry = lookup_widget(pDlg->m_pDialog, "toc_depth_entry");
-	
+
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(use_toc_btn)))
-		gtk_widget_set_sensitive (toc_depth_entry, TRUE);	
+		gtk_widget_set_sensitive (toc_depth_entry, TRUE);
 	else
 		gtk_widget_set_sensitive (toc_depth_entry, FALSE);
 }
@@ -1325,9 +1415,9 @@ void on_enc_unload_checked (GtkMenuItem *menuitem, gpointer user_data)
 
 	GtkWidget *enc_unload_btn = lookup_widget(pDlg->m_pDialog, "enc_unload_btn");
 	GtkWidget *enc_unload_fld = lookup_widget(pDlg->m_pDialog, "enc_unload_fld");
-	
+
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(enc_unload_btn)))
-		gtk_widget_set_sensitive (enc_unload_fld, TRUE);	
+		gtk_widget_set_sensitive (enc_unload_fld, TRUE);
 	else
 		gtk_widget_set_sensitive (enc_unload_fld, FALSE);
 }
@@ -1375,7 +1465,7 @@ void on_icon_internal_clicked(GtkMenuItem *menuitem, gpointer user_data)
 		GtkWidget *cbo2		= lookup_widget(pDlg->m_pDialog, "comboboxentry12");
 		GtkWidget *entry4	= lookup_widget(pDlg->m_pDialog, "entry14");
 		GtkWidget *button	= lookup_widget(pDlg->m_pDialog, "button_xpm_select");
-		
+
 		gtk_widget_set_sensitive(cbo2, TRUE);
 		gtk_widget_set_sensitive(entry4, FALSE);
 		gtk_widget_set_sensitive(button, FALSE);
@@ -1387,7 +1477,7 @@ void on_icon_internal_clicked(GtkMenuItem *menuitem, gpointer user_data)
 void on_icon_custom_clicked(GtkMenuItem *menuitem, gpointer user_data)
 {
 	OptionsDialog *pDlg = (OptionsDialog *)user_data;
-	
+
 	GtkWidget *radio_ico_custom = lookup_widget(pDlg->m_pDialog, "radio_ico_custom");
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_custom)))
 	{
@@ -1443,7 +1533,7 @@ int OptionsDialog::GetIconType()
 
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_none)))
 		return ICON_NONE;
-	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_internal))) 
+	else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ico_internal)))
 		return ICON_INTERNAL;
 	return ICON_CUSTOM;
 }
@@ -1473,7 +1563,7 @@ void OptionsDialog::SetIconType(int nType)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ico_none), TRUE);
 		on_icon_none_clicked(NULL, this);
 	}
-	else if(ICON_CUSTOM == nType) 
+	else if(ICON_CUSTOM == nType)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ico_custom), TRUE);
 	else
 	{
@@ -1543,3 +1633,42 @@ void on_internal_combo_selected (GtkComboBox *widget, gpointer user_data)
 	pDlg->UpdatePreview();
 }
 
+gboolean on_numeric_entry_keypress(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	if( event->type == GDK_KEY_PRESS &&
+		((gdk_keyval_to_unicode (event->keyval) >= '0' && gdk_keyval_to_unicode (event->keyval) <= '9') ||
+		event->keyval == GDK_Left  ||
+		event->keyval == GDK_Right ||
+		event->keyval == GDK_Home  ||
+		event->keyval == GDK_End   ||
+		event->keyval == GDK_Delete	||
+		event->keyval == GDK_BackSpace) )
+		return FALSE; //keep processing
+
+	return TRUE;
+}
+
+gboolean on_numeric_entry_changed(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
+{
+	int nMinValue = GPOINTER_TO_INT(user_data);
+
+	//OptionsDialog *pDlg = (OptionsDialog *)user_data;
+	std::string strValue = gtk_entry_get_text(GTK_ENTRY(widget));
+	if(!strValue.empty())
+	{
+		int nValue = atoi(strValue.c_str());
+		if(nValue < nMinValue)
+		{
+			char szBuffer[30];
+			sprintf(szBuffer, "%d", nMinValue);
+			gtk_entry_set_text(GTK_ENTRY(widget), szBuffer);
+
+			char szMessage[1030];
+			sprintf(szMessage, _("Minimal value is %d sec!"), nMinValue);
+			gtkMessageBox(szMessage);
+			return TRUE;
+		}
+	}
+
+	return FALSE;	//propagate
+}
