@@ -16,17 +16,24 @@
 #include "gui/Dialog.h"
 #include <string>
 
-class OptionsDialog : public Dialog  
+class OptionsDialog : public Dialog
 {
 public:
 	OptionsDialog();
 	virtual ~OptionsDialog();
 
 	virtual void Create();
-	
+
 	void OnDialogInit();
 	void OnDialogOK();
 
+	int  GetIconType();
+	void UpdatePreview();
+	const char *GetIconValue();
+
+	void SetIconType(int nType);
+	void SetIconValue(const char *szValue);
+
 protected:
 	GtkWidget* create_options_dialog (GtkWidget* parent=NULL);
 	std::string m_strLocale;
