@@ -3,7 +3,7 @@
 //
 // This code is licensed under BSD license.See "license.txt" for more details.
 //
-// File: Window class for Password input 
+// File: Window class for Password input
 ////////////////////////////////////////////////////////////////////////////
 
 #ifndef PASSWORDDIALOG_H_
@@ -16,14 +16,17 @@
 #include "gui/Dialog.h"
 #include <string>
 
-class PasswordDialog : public Dialog  
+#define MODE_PASS_VERIFY	0	// type the password once (up to X unsuccessful tries)
+#define MODE_PASS_NEW		1	// type the new password twice (two entry widgets) to eliminate typing errors
+#define MODE_PASS_CHANGE	2	// type the old password once, new password twice (three entry widgets)
+
+class PasswordDialog : public Dialog
 {
 public:
-	PasswordDialog();
+	PasswordDialog(int nMode = MODE_PASS_VERIFY, int nTries = 1);
 	virtual ~PasswordDialog();
 
 	void SetLabel(const char *szText);
-	void SetRequireCheck(bool bRequire){ m_bRequireCheck = bRequire; }
 	void Destroy();
 
 	const char *GetPassword();
@@ -34,9 +37,10 @@ protected:
 	GtkWidget* create_password_dialog (GtkWidget* parent1 = NULL);
 
 public:
-	bool m_bRequireCheck;	// must enter pasword more than once
+	int  m_nDialogMode;		// see defines above
+	int	 m_nNumTries;		// how much times can user fail entering pass
 	int	 m_nEntryCount;
-	std::string m_strEntry;	// 1st entry
+	std::string m_strOldPass;	// when changing password
 };
 
 #endif // PASSWORDDIALOG_H_
