@@ -29,6 +29,7 @@ public:
 
 	//sets locale
 	void Initialize(const char *szIsoCode);
+	void InitializeToSystemLang();
 
 	std::string GetCurLanguage(){ return m_strCurLang; }
 	int  GetCatalogCount(){ return m_lstCatalogs.size(); };
@@ -39,6 +40,7 @@ public:
 	bool IsLocaleAvailable(const char *szLocale);
 
 	int  GetLocaleTableIdx(const char *locale);
+	int	 GetLocaleTableIdx(int nLangID);
 	const char *GetLocale();
 
 	static const char *GetLangName(const char *locale);
