@@ -13,6 +13,7 @@
 #include "../support.h"
 #include "../lib/debug.h"
 #include "../MainWnd.h"
+#include <string.h>
 
 extern MainWindow g_wnd;
 #define PROGRESS_REFRESH_INTERVAL 300
@@ -24,18 +25,26 @@ GtkWidget *g_wndProgressDlg = NULL;
 static GtkWidget *g_progress1 = NULL;
 bool   g_bStartProgress = true;
 
+int ProgressDlg::m_nCurrentSize = 0;
+int ProgressDlg::m_nTotalSize = 0;
+bool ProgressDlg::m_bCanceled = false;
+
 static int progress_timer(gpointer data);
 static int progress_start_timer(gpointer data);
+static void on_abort_clicked(GtkButton *button, gpointer user_data);
 
-ProgressDlg::ProgressDlg(int nWaitMs, const char *szTitle, GtkWidget *pParent)
+ProgressDlg::ProgressDlg(int nWaitMs, const char *szTitle, GtkWidget *pParent, bool bCancelBtn)
 {
 	if(szTitle && strlen(szTitle) > 0)
 		m_strTitle = szTitle;
 
 	m_nProgressTimer = 0;
+	m_nTotalSize	= -1;
+	m_nCurrentSize	= -1;
 
 	m_pDialog = NULL;
 	m_pParent = pParent;
+	m_bCancelBtn = bCancelBtn;
 
 	//start timer
 	g_bStartProgress = true;
@@ -47,6 +56,17 @@ ProgressDlg::~ProgressDlg()
 	Close();
 }
 
+void ProgressDlg::SetTotalSize(int nSize)
+{
+	m_nTotalSize = nSize;
+	m_nCurrentSize = 0;
+}
+	
+void ProgressDlg::SetCurrentSize(int nSize)
+{
+	m_nCurrentSize = nSize;
+}
+
 void ProgressDlg::DoCreateWindow()
 {
 	//show wait dialog
@@ -90,6 +110,15 @@ void ProgressDlg::DoCreateWindow()
 		gtk_widget_show (g_progress1);
 		gtk_box_pack_start (GTK_BOX (vbox1), g_progress1, FALSE, FALSE, 3);
 		
+		if(m_bCancelBtn)
+		{
+			GtkWidget *btnabort = gtk_button_new_with_mnemonic (_("Abort"));
+			gtk_widget_show (btnabort);
+			gtk_box_pack_start (GTK_BOX (vbox1), btnabort, FALSE, FALSE, 3);
+			GTK_WIDGET_SET_FLAGS (btnabort, GTK_CAN_DEFAULT);
+			g_signal_connect(btnabort, "clicked", G_CALLBACK (on_abort_clicked), this);
+		}
+
 		gtk_widget_show (msgbox);
 		gtk_widget_realize(msgbox);
 		m_pDialog = msgbox;
@@ -125,6 +154,12 @@ void ProgressDlg::Close()
 	}
 }
 
+void ProgressDlg::OnCancel()
+{
+	m_bCanceled = true;
+	Close();
+}
+
 gboolean progress_start_timer(gpointer data)
 {
 	if(g_bStartProgress)
@@ -153,9 +188,21 @@ gboolean progress_timer(gpointer data)
 	else
 	{
 		//ensure progress dialog is visible and pulse the progress
-		gtk_widget_show(g_wndProgressDlg);
-		if(g_progress1)
-			gtk_progress_bar_pulse(GTK_PROGRESS_BAR(g_progress1));
+		if(g_wndProgressDlg) gtk_widget_show(g_wndProgressDlg);
+		if(g_progress1){
+			if(ProgressDlg::m_nTotalSize > 0)	//TOFIX what if two loads at te same time ? not static!??
+			{
+				gtk_progress_set_percentage(GTK_PROGRESS(g_progress1), ((double)ProgressDlg::m_nCurrentSize)/ProgressDlg::m_nTotalSize);
+			}
+			else
+				gtk_progress_bar_pulse(GTK_PROGRESS_BAR(g_progress1));
+		}
 	}
 	return TRUE;
 }
+
+void on_abort_clicked (GtkButton *button, gpointer user_data)
+{
+	ProgressDlg *pDlg = (ProgressDlg *)user_data;
+	pDlg->OnCancel();
+}
