@@ -19,11 +19,16 @@
 class ProgressDlg  
 {
 public:
-	ProgressDlg(int nWaitMs = 200, const char *szTitle = NULL, GtkWidget *pParent = NULL);
+	ProgressDlg(int nWaitMs = 200, const char *szTitle = NULL, GtkWidget *pParent = NULL, bool bCancelBtn = false);
 	virtual ~ProgressDlg();
 
+	static void SetTotalSize(int nSize);
+	static void SetCurrentSize(int nSize);
+	static bool IsCanceled(){ return m_bCanceled; };
+
 	void Close();
 	void DoCreateWindow();
+	void OnCancel();
 
 	int m_nStartTimer;
 
@@ -32,6 +37,12 @@ protected:
 	GtkWidget *m_pDialog;
 	GtkWidget *m_pParent;
 	std::string m_strTitle;
+	bool m_bCancelBtn;
+
+public:
+	static int m_nTotalSize;
+	static int m_nCurrentSize;
+	static bool m_bCanceled;
 };
 
 #endif // PROGRESSDLG_H__
