@@ -18,7 +18,7 @@ class FormatIO_HTML : public HTMLParser, public FormatIO_Base
 {
 public:
 	FormatIO_HTML();
-	~FormatIO_HTML();
+	virtual ~FormatIO_HTML();
 
 	virtual int Load(const char *szFile, NoteDocument &doc);
 	virtual int Save(const char *szFile, NoteDocument &doc);
@@ -34,7 +34,7 @@ public:
 
 protected:
 	virtual void OnTagBegin(const char *szTag, const char *szParams = NULL);
-	virtual void OnTagEnd(const char *szTag);	
+	virtual void OnTagEnd(const char *szTag);
 	virtual void OnComment(const char *szText);
 	virtual void OnText(const char *szText);
 	void WriteDocContents(IOProcess &objFile);
@@ -64,4 +64,3 @@ protected:
 };
 
 #endif
-
