@@ -16,7 +16,7 @@ class FormatIO_StickyNotes : public HTMLParser, public FormatIO_Base
 {
 public:
 	FormatIO_StickyNotes();
-	~FormatIO_StickyNotes();
+	virtual ~FormatIO_StickyNotes();
 
 	virtual int Load(const char *szFile, NoteDocument &doc);
 	virtual int Save(const char *szFile, NoteDocument &doc);
@@ -27,7 +27,7 @@ public:
 
 protected:
 	virtual void OnTagBegin(const char *szTag, const char *szParams = NULL);
-	virtual void OnTagEnd(const char *szTag);	
+	virtual void OnTagEnd(const char *szTag);
 	virtual void OnComment(const char *szText);
 	virtual void OnText(const char *szText);
 
@@ -40,4 +40,3 @@ protected:
 };
 
 #endif
-
