@@ -131,6 +131,9 @@ int APIENTRY WinMain(HINSTANCE hInstance,
 
 	if(0 == _access(strGtk.c_str(), 0))	// GTK directory exists
 	{
+		//set variable so Notecase can detect portable mode in an easy way
+		_putenv("NOTECASE_PORTABLE=1");
+
 		//set directory for INI file
 		char szBuffer[10024];
 		_snprintf(szBuffer, sizeof(szBuffer)-1, "NOTECASE_HOME=%s", strDir.c_str());
@@ -156,14 +159,14 @@ int APIENTRY WinMain(HINSTANCE hInstance,
 		const char *szPath = getenv("PATH");
 		int nLen = strlen(szPath);
 		std::string strGtkBin = strGtk + "bin\\";
-		_snprintf(szBuffer, sizeof(szBuffer)-1, "PATH=%s;%s;%s", szPath, strGtk.c_str(), strGtkBin.c_str());
+		_snprintf(szBuffer, sizeof(szBuffer)-1, "PATH=%s;%s;%s", strGtk.c_str(), strGtkBin.c_str(), szPath);
 		szBuffer[sizeof(szBuffer)-1] = '\0';
 		_putenv(szBuffer);
 
 		std::string strURL = strDir;
 		strURL += "app\\Notecase.exe";
 
-		HINSTANCE hInstance = ShellExecute(NULL, "open", strURL.c_str(), "", "", SW_SHOW);
+		HINSTANCE hInstance = ShellExecute(NULL, "open", strURL.c_str(), (NULL != lpCmdLine) ? lpCmdLine : "", "", SW_SHOW);
 		DWORD result = reinterpret_cast<DWORD>(hInstance);
 		if (result <= HINSTANCE_ERROR)
 		{
